<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version='1.0'
                xmlns="http://www.w3.org/1999/xhtml"
                exclude-result-prefixes="#default">

    <xsl:import href="http://docbook.sourceforge.net/release/xsl/current/xhtml/docbook.xsl"/>
    <xsl:import href="../../../xsl/html-single.xsl"/>

    <!-- Change Japanese name order to first-last BZ#1063105 -->
    <xsl:param name="local.l10n.xml" select="document('')"/>
      <l:i18n xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">
        <l:l10n language="ja">
          <l:context name="styles">
            <l:template name="person-name" text="first-last"/>
          </l:context>
        </l:l10n>
      </l:i18n>

    <!-- We don't want navigation titles -->
    <xsl:param name="navig.showtitles" select="0"/>

    <xsl:template name="user.head.content">
        <xsl:if test="$embedtoc != 0">
            <xsl:element name="link">
                <xsl:attribute name="rel">stylesheet</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of select="$prod.url"/>/chrome_themes/umbra/s/chrometwo.css</xsl:attribute>
            </xsl:element>
            <xsl:element name="script">
                <xsl:attribute name="src"><xsl:value-of select="$prod.url"/>/webassets/avalon/j/lib/require.js</xsl:attribute>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <xsl:template name="body.attributes">
        <xsl:if test="starts-with($writing.mode, 'rl')">
	    <xsl:attribute name="dir">rtl</xsl:attribute>
        </xsl:if>
        <xsl:variable name="class">
            <xsl:if test="($draft.mode = 'yes' or ($draft.mode = 'maybe' and (ancestor-or-self::set | ancestor-or-self::book | ancestor-or-self::article)[1]/@status = 'draft'))">
               <xsl:value-of select="ancestor-or-self::*[@status][1]/@status"/><xsl:text> </xsl:text>
            </xsl:if>
            <xsl:if test="$embedtoc != 0">
                <xsl:text>chrometwo </xsl:text>
            </xsl:if>
            <xsl:if test="$desktop != 0">
                <xsl:text>desktop </xsl:text>
            </xsl:if>
	</xsl:variable>
        <xsl:if test="$class != ''">
            <xsl:attribute name="class">
                <xsl:value-of select="concat($class, @class)"/>
	    </xsl:attribute>
	</xsl:if>
    </xsl:template>

    <!--
    From: html-single.xsl
    Reason: add chroming divs
    -->

    <xsl:template match="*" mode="process.root">
        <xsl:variable name="doc" select="self::*"/>

        <xsl:call-template name="user.preroot"/>
        <xsl:call-template name="root.messages"/>

        <xsl:choose>
            <xsl:when test="$body.only != 0">
                <xsl:apply-templates select="."/>
            </xsl:when>
            <xsl:otherwise>
                <!--
                    mcasperson 30 Sep 2013: chrometwo class required
                -->
                <html class="chrometwo">
                    <head>
                        <xsl:call-template name="system.head.content">
                            <xsl:with-param name="node" select="$doc"/>
                        </xsl:call-template>
                        <xsl:call-template name="head.content">
                            <xsl:with-param name="node" select="$doc"/>
                        </xsl:call-template>
                        <xsl:call-template name="user.head.content">
                            <xsl:with-param name="node" select="$doc"/>
                        </xsl:call-template>
                    </head>
                    <body>
                        <xsl:call-template name="body.attributes"/>
                        <div id="chrometwo">
                            <div id="main">
                                <xsl:call-template name="user.header.content">
                                    <xsl:with-param name="node" select="$doc"/>
                                </xsl:call-template>
                                <xsl:if test="$embedtoc != 0">
                                    <div id="navigation"></div>
                                </xsl:if>
                                <xsl:if test="$embedtoc = 0 or $web.type = '' and navig.showtitles != 0">
                                    <p xmlns="http://www.w3.org/1999/xhtml">
                                        <xsl:attribute name="id">
                                            <xsl:text>title</xsl:text>
                                        </xsl:attribute>
                                        <a class="left">
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="$prod.url"/>
                                            </xsl:attribute>
                                            <img alt="Product Site">
                                                <xsl:attribute name="src">
                                                    <xsl:value-of select="$admon.graphics.path"/><xsl:text>/image_left.png</xsl:text>
                                                </xsl:attribute>
                                            </img>
                                        </a>
                                        <a class="right">
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="$prod.url"/>
                                            </xsl:attribute>
                                            <img alt="Documentation Site">
                                                <xsl:attribute name="src">
                                                    <xsl:value-of select="$admon.graphics.path"/><xsl:text>/image_right.png</xsl:text>
                                                </xsl:attribute>
                                            </img>
                                        </a>
                                    </p>
                                </xsl:if>
                                <xsl:if test="$embedtoc != 0 and $web.type = ''">
                                    <div id="nodocnav"></div>
                                </xsl:if>
                                <xsl:apply-templates select="."/>
                                <xsl:call-template name="user.footer.content">
                                    <xsl:with-param name="node" select="$doc"/>
                                </xsl:call-template>
                            </div>
                        </div>
                        <xsl:if test="$embedtoc != 0">
                            <!-- lnewson 17 Oct 2013: reworked breadcrumbs to use the portal api -->
                            <script type="text/javascript">
                                <xsl:if test="$web.type = ''">
                                    current_book = '<xsl:copy-of select="$pop_name"/>';
                                    current_version = '<xsl:copy-of select="$pop_ver"/>';
                                    current_product = '<xsl:copy-of select="$pop_prod"/>';
                                </xsl:if>
                                <xsl:if test="$web.type != ''">
                                    current_book = '';
                                    current_version = '';
                                </xsl:if>

                                initializeBreadcrumbs('<xsl:value-of select="$tocpath"/>', current_product, current_version, current_book);
                            </script>
                        </xsl:if>
                    </body>
                </html>
                <xsl:value-of select="$html.append"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:param name="generate.toc">
        set toc
        book toc
        article toc
        chapter toc
        qandadiv toc
        qandaset toc
        sect1 nop
        sect2 nop
        sect3 nop
        sect4 nop
        sect5 nop
        section toc
        part toc
    </xsl:param>

    <!--
    From: xhtml-common.xsl
    Reason: Add JavaScript wrapper
    Version: 1.72.0
    -->
    <xsl:template name="user.footer.content">
        <xsl:param name="node" select="."/>
        <xsl:if test="$confidential = '1'">
            <div xmlns="http://www.w3.org/1999/xhtml" class="confidential">
                <xsl:value-of select="$confidential.text"/>
            </div>
        </xsl:if>
	<!-- remove reference to non-existent footer.html BZ#1056758 -->
    </xsl:template>

    <!--
    From: xhtml-common.xsl
    Reason: Remove old unwrapped JavaScript
    -->
    <xsl:template name="head.content">
        <xsl:param name="node" select="."/>
        <xsl:param name="title">
            <xsl:apply-templates select="$node" mode="object.title.markup.textonly"/>
        </xsl:param>

        <title xmlns="http://www.w3.org/1999/xhtml" >
            <xsl:copy-of select="$title"/>
        </title>

        <xsl:if test="$html.stylesheet != ''">
            <xsl:call-template name="output.html.stylesheets">
                <xsl:with-param name="stylesheets" select="normalize-space($html.stylesheet)"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:if test="$html.stylesheet.print != ''">
            <link rel="stylesheet" media="print">
                <xsl:attribute name="href">
                    <xsl:value-of select="$html.stylesheet.print"/>
                </xsl:attribute>
                <xsl:if test="$html.stylesheet.type != ''">
                    <xsl:attribute name="type">
                        <xsl:value-of select="$html.stylesheet.type"/>
                    </xsl:attribute>
                </xsl:if>
            </link>
        </xsl:if>

        <xsl:if test="$link.mailto.url != ''">
            <link rev="made" href="{$link.mailto.url}"/>
        </xsl:if>

        <xsl:if test="$html.base != ''">
            <base href="{$html.base}"/>
        </xsl:if>

        <meta xmlns="http://www.w3.org/1999/xhtml" name="generator">
            <xsl:attribute name="content">
                <xsl:text>publican </xsl:text><xsl:value-of select="$publican.version"/>
            </xsl:attribute>
        </meta>

        <meta xmlns="http://www.w3.org/1999/xhtml" name="package">
            <xsl:attribute name="content">
                <xsl:copy-of select="$package"/>
            </xsl:attribute>
        </meta>
        <xsl:if test="$generate.meta.abstract != 0">
            <xsl:variable name="info" select="(articleinfo |bookinfo |prefaceinfo |chapterinfo |appendixinfo |sectioninfo |sect1info |sect2info |sect3info |sect4info |sect5info |referenceinfo |refentryinfo |partinfo |info |docinfo)[1]"/>
            <xsl:if test="$info and $info/abstract">
                <meta xmlns="http://www.w3.org/1999/xhtml" name="description">
                    <xsl:attribute name="content">
                        <xsl:for-each select="$info/abstract[1]/*">
                            <xsl:value-of select="normalize-space(.)"/>
                            <xsl:if test="position() &lt; last()">
                                <xsl:text> </xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:attribute>
                </meta>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$embedtoc != 0 ">
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../chrome.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../db4.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../<xsl:value-of select="$brand"/>/<xsl:value-of select="$langpath"/>/css/brand.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../print.css</xsl:attribute><xsl:attribute name="media">print</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../site_overrides.css</xsl:attribute></link>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/../jquery-1.7.1.min.js</xsl:attribute></script>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/labels.js</xsl:attribute></script>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/../toc.js</xsl:attribute></script>
        </xsl:if>

        <xsl:apply-templates select="." mode="head.keywords.content"/>
    </xsl:template>

</xsl:stylesheet>

