<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version='1.0'
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:ext="http://exslt.org/common"
                exclude-result-prefixes="#default">

    <xsl:import href="http://docbook.sourceforge.net/release/xsl/current/xhtml/docbook.xsl"/>
    <xsl:import href="../../../xsl/html.xsl"/>

    <!-- Change Japanese name order to first-last BZ#1063105 -->
    <xsl:param name="local.l10n.xml" select="document('')"/>
      <l:i18n xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">
        <l:l10n language="ja">
          <l:context name="styles">
            <l:template name="person-name" text="first-last"/>
          </l:context>
        </l:l10n>
      </l:i18n>
      
    <!-- Adding chroming to head -->
    <xsl:template name="user.head.content">
        <xsl:if test="$embedtoc != 0">
            <xsl:element name="link">
                <xsl:attribute name="rel">stylesheet</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of select="$prod.url"/>/chrome_themes/umbra/s/chrometwo.css</xsl:attribute>
            </xsl:element>
            <xsl:element name="script">
                <xsl:attribute name="src"><xsl:value-of select="$prod.url"/>/webassets/avalon/j/lib/require.js</xsl:attribute>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <!-- We want footer nav -->
    <xsl:param name="suppress.footer.navigation" select="0"/>
    <xsl:param name="suppress.navigation" select="0"/>

    <!-- Adding chrometwo class to body -->
    <xsl:template name="body.attributes">
        <xsl:if test="starts-with($writing.mode, 'rl')">
	    <xsl:attribute name="dir">rtl</xsl:attribute>
        </xsl:if>
        <xsl:variable name="class">
            <xsl:if test="($draft.mode = 'yes' or ($draft.mode = 'maybe' and (ancestor-or-self::set | ancestor-or-self::book | ancestor-or-self::article)[1]/@status = 'draft'))">
               <xsl:value-of select="ancestor-or-self::*[@status][1]/@status"/><xsl:text> </xsl:text>
            </xsl:if>
            <xsl:if test="$embedtoc != 0">
                <xsl:text>chrometwo </xsl:text>
            </xsl:if>
            <xsl:if test="$desktop != 0">
                <xsl:text>desktop </xsl:text>
            </xsl:if>
	</xsl:variable>
        <xsl:if test="$class != ''">
            <xsl:attribute name="class">
                <xsl:value-of select="concat($class, @class)"/>
	    </xsl:attribute>
	</xsl:if>
    </xsl:template>

    <!--
    From: html.xsl
    Reason: add chroming divs
    -->
    <xsl:template name="chunk-element-content">
        <xsl:param name="prev"/>
        <xsl:param name="next"/>
        <xsl:param name="nav.context"/>
        <xsl:param name="content">
            <xsl:apply-imports/>
        </xsl:param>

        <xsl:call-template name="user.preroot"/>

        <!--
            mcasperson 30 Sep 2013: chrometwo class required
        -->
        <html class="chrometwo">
            <xsl:call-template name="html.head">
                <xsl:with-param name="prev" select="$prev"/>
                <xsl:with-param name="next" select="$next"/>
            </xsl:call-template>

            <body>
                <xsl:call-template name="body.attributes"/>
                <div id="chrometwo">
                    <div id="main">
                        <xsl:if test="$embedtoc != 0">
                            <div id="navigation"></div>
                        </xsl:if>
                        <xsl:call-template name="user.header.navigation"/>
                        <xsl:call-template name="header.navigation">
                            <xsl:with-param name="prev" select="$prev"/>
                            <xsl:with-param name="next" select="$next"/>
                            <xsl:with-param name="nav.context" select="$nav.context"/>
                        </xsl:call-template>

                        <xsl:call-template name="user.header.content"/>

                        <xsl:copy-of select="$content"/>

                        <xsl:call-template name="user.footer.content"/>

                        <xsl:call-template name="footer.navigation">
                            <xsl:with-param name="prev" select="$prev"/>
                            <xsl:with-param name="next" select="$next"/>
                            <xsl:with-param name="nav.context" select="$nav.context"/>
                        </xsl:call-template>

                        <xsl:call-template name="user.footer.navigation"/>                        
                    </div>
                </div>
                <xsl:if test="$embedtoc != 0">
                    <!-- lnewson 17 Oct 2013: reworked breadcrumbs to use the portal api -->
                    <script type="text/javascript">
                        <xsl:if test="$web.type = ''">
                            current_book = '<xsl:copy-of select="$pop_name"/>';
                            current_version = '<xsl:copy-of select="$pop_ver"/>';
                            current_product = '<xsl:copy-of select="$pop_prod"/>';
                        </xsl:if>
                        <xsl:if test="$web.type != ''">
                            current_book = '';
                            current_version = '';
                        </xsl:if>

                        initializeBreadcrumbs('<xsl:value-of select="$tocpath"/>', current_product, current_version, current_book);
                    </script>
                </xsl:if>
            </body>
        </html>
        <xsl:value-of select="$chunk.append"/>
    </xsl:template>

    <!-- Templates for TOC menu -->
    <xsl:template match="node()" mode="pass2">
        <xsl:copy>
            <xsl:apply-templates select="node()" mode="pass2"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="/*" mode="pass2">
        <xsl:copy>
            <xsl:copy-of select="@*"/>
            <xsl:apply-templates mode="pass2"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="*[local-name() = 'dl']" mode="pass2">
        <xsl:variable name="book">
            <xsl:copy-of select="$pop_name"/>
        </xsl:variable>
        <xsl:variable name="bookname" select="translate($book,'_',' ')"/>
        <select class="pageSelect">
            <xsl:element name="option">
                <xsl:attribute name="value">
                    <xsl:text>index.html</xsl:text>
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>menu-level-0</xsl:text>
                </xsl:attribute>
                <xsl:call-template name="gentext.doc.home">
                </xsl:call-template>
            </xsl:element>
            <xsl:apply-templates select="node()" mode="pass2"/>
        </select>
    </xsl:template>

    <xsl:template match="*[local-name() = 'dt']" mode="pass2">
        <xsl:element name="option">
            <xsl:apply-templates select="node()" mode="pass2"/>
        </xsl:element>
    </xsl:template>

    <xsl:template match="*[local-name() = 'dd']" mode="pass2">
        <xsl:apply-templates select="*/*" mode="pass2"/>
    </xsl:template>

    <xsl:template match="*[local-name() = 'span']" mode="pass2">
        <xsl:apply-templates select="node()" mode="pass2"/>
    </xsl:template>

    <xsl:template match="*[local-name() = 'a']" mode="pass2">
        <xsl:attribute name="value">
            <xsl:value-of select="@href"/>
        </xsl:attribute>
        <xsl:attribute name="class">
            <xsl:value-of select="concat('menu-level-', count(ancestor::*[local-name() = 'dd']))"/>
        </xsl:attribute>
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:param name="generate.toc">
        set toc
        book toc
        article toc
        chapter toc
        qandadiv toc
        qandaset toc
        sect1 nop
        sect2 nop
        sect3 nop
        sect4 nop
        sect5 nop
        section toc
        part toc
    </xsl:param>

    <!--
    From: html.xsl
    Reason: Add TOC menu to nav
    -->
    <xsl:template name="header.navigation">
        <xsl:param name="prev" select="/foo"/>
        <xsl:param name="next" select="/foo"/>
        <xsl:param name="nav.context"/>
        <xsl:variable name="home" select="/*[1]"/>
        <xsl:variable name="row1" select="$embedtoc = '0' and $navig.showtitles != '0'"/>
        <xsl:variable name="row2" select="count($prev) &gt; 0 or count($next) &gt; 0"/>
        <xsl:if test="$suppress.navigation = '0' and $suppress.header.navigation = '0'">
            <xsl:if test="$row1 or $row2">
                <xsl:if test="$row1">
                    <p xmlns="http://www.w3.org/1999/xhtml">
                        <xsl:attribute name="id">
                            <xsl:text>title</xsl:text>
                        </xsl:attribute>
                        <a class="left">
                            <xsl:attribute name="href">
                                <xsl:value-of select="$prod.url"/>
                            </xsl:attribute>
                            <img alt="Product Site">
                                <xsl:attribute name="src">
                                    <xsl:value-of select="$admon.graphics.path"/><xsl:text>/image_left.png</xsl:text>
                                </xsl:attribute>
                            </img>
                        </a>
                        <a class="right">
                            <xsl:attribute name="href">
                                <xsl:value-of select="$prod.url"/>
                            </xsl:attribute>
                            <img alt="Documentation Site">
                                <xsl:attribute name="src">
                                    <xsl:value-of select="$admon.graphics.path"/><xsl:text>/image_right.png</xsl:text>
                                </xsl:attribute>
                            </img>
                        </a>
                    </p>
                </xsl:if>
                <xsl:if test="$row2">
                    <ul class="docnav top" xmlns="http://www.w3.org/1999/xhtml">
                        <li class="previous">
                            <xsl:if test="count($prev)&gt;0">
                                <a accesskey="p">
                                    <xsl:attribute name="href">
                                        <xsl:call-template name="href.target">
                                            <xsl:with-param name="object" select="$prev"/>
                                        </xsl:call-template>
                                    </xsl:attribute>
                                    <strong>
                                        <xsl:call-template name="navig.content">
                                            <xsl:with-param name="direction" select="'prev'"/>
                                        </xsl:call-template>
                                    </strong>
                                </a>
                            </xsl:if>
                        </li>
                        <xsl:choose>
                            <xsl:when test="$embedtoc != 0">
                                <li class="doctoc">
                                    <xsl:variable name="doctoc.menu">
                                        <xsl:call-template name="division.toc">
                                            <xsl:with-param name="toc-context" select="."/>
                                            <xsl:with-param name="toc.title.p" select="false()"/>
                                        </xsl:call-template>
                                    </xsl:variable>
                                    <xsl:choose>
                                        <xsl:when test="not($doctoc.menu = '')">
                                            <xsl:apply-templates select="ext:node-set($doctoc.menu)" mode="pass2"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:variable name="doctoc.menu.2">
                                                <xsl:call-template name="component.toc">
                                                    <xsl:with-param name="toc-context" select="."/>
                                                    <xsl:with-param name="toc.title.p" select="false()"/>
                                                </xsl:call-template>
                                            </xsl:variable>
                                            <xsl:apply-templates select="ext:node-set($doctoc.menu.2)" mode="pass2"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </li>
                            </xsl:when>
                            <xsl:otherwise>
                                <li class="home"><xsl:value-of select="$clean_title"/></li>
                            </xsl:otherwise>
                        </xsl:choose>
                        <li class="next">
                            <xsl:if test="count($next)&gt;0">
                                <a accesskey="n">
                                    <xsl:attribute name="href">
                                        <xsl:call-template name="href.target">
                                            <xsl:with-param name="object" select="$next"/>
                                        </xsl:call-template>
                                    </xsl:attribute>
                                    <strong>
                                        <xsl:call-template name="navig.content">
                                            <xsl:with-param name="direction" select="'next'"/>
                                        </xsl:call-template>
                                    </strong>
                                </a>
                            </xsl:if>
                        </li>
                    </ul>
                </xsl:if>
            </xsl:if>

            <xsl:if test="$header.rule != 0">
                <hr/>
            </xsl:if>
        </xsl:if>
    </xsl:template>

    <!--
    From: html.xsl
    Reason: Adding TOC menu to footer nav
    -->
    <xsl:template name="footer.navigation">
        <xsl:param name="prev" select="/foo"/>
        <xsl:param name="next" select="/foo"/>
        <xsl:param name="nav.context"/>
        <xsl:param name="title-limit" select="'50'"/>
        <xsl:variable name="home" select="/*[1]"/>
        <xsl:variable name="up" select="parent::*"/>
        <xsl:variable name="row1" select="count($prev) &gt; 0 or count($next) &gt; 0"/>

        <xsl:if test="$suppress.navigation = '0' and $suppress.footer.navigation = '0'">
            <xsl:if test="$footer.rule != 0">
                <hr/>
            </xsl:if>
            <xsl:if test="$row1">
                <ul class="docnav bottom" xmlns="http://www.w3.org/1999/xhtml">
                    <xsl:if test="$row1">
                        <li class="previous">
                            <xsl:if test="count($prev) &gt; 0">
                                <a accesskey="p">
                                    <xsl:attribute name="href">
                                        <xsl:call-template name="href.target">
                                            <xsl:with-param name="object" select="$prev"/>
                                        </xsl:call-template>
                                    </xsl:attribute>
                                    <strong>
                                        <xsl:call-template name="navig.content">
                                            <xsl:with-param name="direction" select="'prev'"/>
                                        </xsl:call-template>
                                    </strong>
                                    <xsl:if test="$embedtoc = '0'">
                                        <xsl:variable name="text">
                                            <xsl:apply-templates select="$prev" mode="object.title.markup"/>
                                        </xsl:variable>
                                        <xsl:choose>
                                            <xsl:when test="string-length($text) &gt; $title-limit">
                                                <xsl:value-of select="concat(substring($text, 0, $title-limit), '...')"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="$text"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:if>
                                </a>
                            </xsl:if>
                        </li>
                        <xsl:choose>
                            <xsl:when test="$embedtoc != 0">
                                <li class="doctoc">
                                    <xsl:variable name="doctoc.menu">
                                        <xsl:call-template name="division.toc">
                                            <xsl:with-param name="toc-context" select="."/>
                                            <xsl:with-param name="toc.title.p" select="false()"/>
                                        </xsl:call-template>
                                    </xsl:variable>
                                    <xsl:choose>
                                        <xsl:when test="not($doctoc.menu = '')">
                                            <xsl:apply-templates select="ext:node-set($doctoc.menu)" mode="pass2"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:variable name="doctoc.menu.2">
                                                <xsl:call-template name="component.toc">
                                                    <xsl:with-param name="toc-context" select="."/>
                                                    <xsl:with-param name="toc.title.p" select="false()"/>
                                                </xsl:call-template>
                                            </xsl:variable>
                                            <xsl:apply-templates select="ext:node-set($doctoc.menu.2)" mode="pass2"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </li>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:if test="count($up) &gt; 0">
                                    <li class="up">
                                            <a accesskey="u">
                                                    <xsl:attribute name="href">
                                                            <xsl:text>#</xsl:text>
                                                    </xsl:attribute>
                                                    <strong>
                                                            <xsl:call-template name="navig.content">
                                                                    <xsl:with-param name="direction" select="'up'"/>
                                                            </xsl:call-template>
                                                    </strong>
                                            </a>
                                    </li>
                                </xsl:if>
                                <xsl:if test="$home != . or $nav.context = 'toc'">
                                    <li class="home">
                                            <a accesskey="h">
                                                    <xsl:attribute name="href">
                                                            <xsl:call-template name="href.target">
                                                                    <xsl:with-param name="object" select="$home"/>
                                                            </xsl:call-template>
                                                    </xsl:attribute>
                                                    <strong>
                                                            <xsl:call-template name="navig.content">
                                                                    <xsl:with-param name="direction" select="'home'"/>
                                                            </xsl:call-template>
                                                    </strong>
                                            </a>
                                    </li>
                                </xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:if test="count($next)&gt;0">
                            <li class="next">
                                <a accesskey="n">
                                    <xsl:attribute name="href">
                                        <xsl:call-template name="href.target">
                                            <xsl:with-param name="object" select="$next"/>
                                        </xsl:call-template>
                                    </xsl:attribute>
                                    <strong>
                                        <xsl:call-template name="navig.content">
                                            <xsl:with-param name="direction" select="'next'"/>
                                        </xsl:call-template>
                                    </strong>
                                    <xsl:if test="$embedtoc = '0'">
                                        <xsl:variable name="text">
                                           	<xsl:apply-templates select="$next" mode="object.title.markup"/>
                                       	</xsl:variable>
                                       	<xsl:choose>
                                            <xsl:when test="string-length($text) &gt; $title-limit">
                                                <xsl:value-of select="concat(substring($text, 0, $title-limit),'...')"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="$text"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:if>
                                </a>
                            </li>
                        </xsl:if>
                    </xsl:if>
                </ul>
            </xsl:if>
        </xsl:if>
    </xsl:template>


    <!--
    From: xhtml-common.xsl
    Reason: Add JavaScript wrapper
    Version: 1.72.0
    -->
    <xsl:template name="user.footer.content">
        <xsl:param name="node" select="."/>
        <xsl:if test="$confidential = '1'">
            <div xmlns="http://www.w3.org/1999/xhtml" class="confidential">
                <xsl:value-of select="$confidential.text"/>
            </div>
        </xsl:if>
        <!-- remove reference to non-existent footer.html BZ#1056758 -->
    </xsl:template>

    <!--
    From: xhtml-common.xsl
    Reason: Remove old unwrapped JavaScript
    -->
    <xsl:template name="head.content">
        <xsl:param name="node" select="."/>
        <xsl:param name="title">
            <xsl:apply-templates select="$node" mode="object.title.markup.textonly"/>
        </xsl:param>

        <title xmlns="http://www.w3.org/1999/xhtml" >
            <xsl:copy-of select="$title"/>
        </title>

        <xsl:if test="$html.stylesheet != ''">
            <xsl:call-template name="output.html.stylesheets">
                <xsl:with-param name="stylesheets" select="normalize-space($html.stylesheet)"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:if test="$html.stylesheet.print != ''">
            <link rel="stylesheet" media="print">
                <xsl:attribute name="href">
                    <xsl:value-of select="$html.stylesheet.print"/>
                </xsl:attribute>
                <xsl:if test="$html.stylesheet.type != ''">
                    <xsl:attribute name="type">
                        <xsl:value-of select="$html.stylesheet.type"/>
                    </xsl:attribute>
                </xsl:if>
            </link>
        </xsl:if>

        <xsl:if test="$link.mailto.url != ''">
            <link rev="made" href="{$link.mailto.url}"/>
        </xsl:if>

        <xsl:if test="$html.base != ''">
            <base href="{$html.base}"/>
        </xsl:if>

        <meta xmlns="http://www.w3.org/1999/xhtml" name="generator">
            <xsl:attribute name="content">
                <xsl:text>publican </xsl:text><xsl:value-of select="$publican.version"/>
            </xsl:attribute>
        </meta>

        <meta xmlns="http://www.w3.org/1999/xhtml" name="package">
            <xsl:attribute name="content">
                <xsl:copy-of select="$package"/>
            </xsl:attribute>
        </meta>
        <xsl:if test="$generate.meta.abstract != 0">
            <xsl:variable name="info" select="(articleinfo |bookinfo |prefaceinfo |chapterinfo |appendixinfo |sectioninfo |sect1info |sect2info |sect3info |sect4info |sect5info |referenceinfo |refentryinfo |partinfo |info |docinfo)[1]"/>
            <xsl:if test="$info and $info/abstract">
                <meta xmlns="http://www.w3.org/1999/xhtml" name="description">
                    <xsl:attribute name="content">
                        <xsl:for-each select="$info/abstract[1]/*">
                            <xsl:value-of select="normalize-space(.)"/>
                            <xsl:if test="position() &lt; last()">
                                <xsl:text> </xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:attribute>
                </meta>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$embedtoc != 0 ">
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../chrome.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../db4.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../<xsl:value-of select="$brand"/>/<xsl:value-of select="$langpath"/>/css/brand.css</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../print.css</xsl:attribute><xsl:attribute name="media">print</xsl:attribute></link>
            <link rel="stylesheet" type="text/css"><xsl:attribute name="href"><xsl:value-of select="$tocpath"/>/../site_overrides.css</xsl:attribute></link>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/../jquery-1.7.1.min.js</xsl:attribute></script>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/labels.js</xsl:attribute></script>
            <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$tocpath"/>/../toc.js</xsl:attribute></script>
        </xsl:if>

        <xsl:apply-templates select="." mode="head.keywords.content"/>
    </xsl:template>

    <!-- Localisation for 'document home' string -->
    <xsl:param name="local.l10n.xml" select="document('')"/>
    <l:i18n xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">
        <l:l10n language="en">
            <l:gentext key="document-home" text="Document Home"/>
        </l:l10n>
        <l:l10n language="as">
            <l:gentext key="document-home" text="দস্তাবেজৰ ঘৰ"/>
        </l:l10n>
        <l:l10n language="bn_in">
            <l:gentext key="document-home" text="নথির প্রথম পাতা"/>
        </l:l10n>
        <l:l10n language="de">
            <l:gentext key="document-home" text="Dokument Startseite"/>
        </l:l10n>
        <l:l10n language="es">
            <l:gentext key="document-home" text="Página de inicio del documento"/>
        </l:l10n>
        <l:l10n language="fr">
            <l:gentext key="document-home" text="Accueil du document"/>
        </l:l10n>
        <l:l10n language="gu">
            <l:gentext key="document-home" text="દસ્તાવેજ ઘર"/>
        </l:l10n>
        <l:l10n language="hi">
            <l:gentext key="document-home" text="दस्तावेज़ मुखपृष्ठ"/>
        </l:l10n>
        <l:l10n language="it">
            <l:gentext key="document-home" text="Home del documento"/>
        </l:l10n>
        <l:l10n language="ja">
            <l:gentext key="document-home" text="ドキュメントホーム"/>
        </l:l10n>
        <l:l10n language="kn">
            <l:gentext key="document-home" text="ದಸ್ತಾವೇಜಿನ ನೆಲೆ"/>
        </l:l10n>
        <l:l10n language="ko">
            <l:gentext key="document-home" text="문서 홈 "/>
        </l:l10n>
        <l:l10n language="ml">
            <l:gentext key="document-home" text="രേഖയുടെ ആസ്ഥാനം"/>
        </l:l10n>
        <l:l10n language="mr">
            <l:gentext key="document-home" text="दस्तऐवजाचे होम"/>
        </l:l10n>
        <l:l10n language="or">
            <l:gentext key="document-home" text="ଦଲିଲ ମୂଳ ସ୍ଥାନ"/>
        </l:l10n>
        <l:l10n language="pa">
            <l:gentext key="document-home" text="ਦਸਤਾਵੇਜ ਮੁੱਖ-ਸਫ਼ਾ"/>
        </l:l10n>
        <l:l10n language="pt_br">
            <l:gentext key="document-home" text="Home to Documento"/>
        </l:l10n>
        <l:l10n language="ru">
            <l:gentext key="document-home" text="В начало"/>
        </l:l10n>
        <l:l10n language="ta">
            <l:gentext key="document-home" text="ஆவண முகப்பு"/>
        </l:l10n>
        <l:l10n language="te">
            <l:gentext key="document-home" text="పత్రము నివాసం"/>
        </l:l10n>
        <l:l10n language="zh_cn">
            <l:gentext key="document-home" text="文档主页"/>
        </l:l10n>
        <l:l10n language="zh_tw">
            <l:gentext key="document-home" text="文件首頁"/>
        </l:l10n>
    </l:i18n>

    <xsl:template name="gentext.doc.home">
        <xsl:call-template name="gentext">
            <xsl:with-param name="key" select="'document-home'"/>
        </xsl:call-template>
    </xsl:template>

</xsl:stylesheet>
